aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSeongJae Park <sj@kernel.org>2024-04-21 09:29:21 -0700
committerSeongJae Park <sj@kernel.org>2024-04-21 09:29:21 -0700
commit69eb6c434f4067f64d5fed0dc6f4ff680fcf3d7e (patch)
tree876275a130119307809110ec4ae8f27aa3ace9c0
parent01def38580612da18b0d789d0eb9acab2090ee53 (diff)
downloaddamo-69eb6c434f4067f64d5fed0dc6f4ff680fcf3d7e.tar.gz
_damo_records: Rename MemFootprint to ProcMemFootprint
Signed-off-by: SeongJae Park <sj@kernel.org>
-rw-r--r--_damo_records.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/_damo_records.py b/_damo_records.py
index 9da8c93b..c21f927b 100644
--- a/_damo_records.py
+++ b/_damo_records.py
@@ -500,7 +500,7 @@ def update_records_file(file_path, file_format, file_permission=None,
# memory footprint recording
# Meaning of the fileds of MemFootprint are as below.
#
# ======== =============================== ==============================
# Field Content
@@ -519,7 +519,7 @@ def update_records_file(file_path, file_format, file_permission=None,
#
# The above table is tolen from Documentation/filesystems/proc.rst file of
# Linux
-class MemFootprint:
+class ProcMemFootprint:
size = None
resident = None
shared = None
@@ -572,7 +572,7 @@ class MemFootprintsSnapshot:
self.time = time.time()
self.footprints = {}
for pid in pids:
- self.footprints[pid] = MemFootprint(pid)
+ self.footprints[pid] = ProcMemFootprint(pid)
def to_kvpairs(self):
footprints = []
@@ -587,7 +587,7 @@ class MemFootprintsSnapshot:
self.footprints = {}
for fp in kvpairs['footprints']:
pid, footprint = fp['pid'], fp['footprint']
- self.footprints[pid] = MemFootprint.from_kvpairs(footprint)
+ self.footprints[pid] = ProcMemFootprint.from_kvpairs(footprint)
return self
def record_mem_footprint(kdamonds, snapshots):
@@ -500,7 +500,7 @@ def update_records_file(file_path, file_format, file_permission=None,
# memory footprint recording
-# Meaning of the fileds of MemFootprint are as below.
+# Meaning of the fileds of ProcMemFootprint are as below.
#
# ======== =============================== ==============================